@@ -27,11 +27,12 @@ use InSilicoSpectro::InSilico::AASequence;
 use InSilicoSpectro::InSilico::CleavEnzyme;
 use InSilicoSpectro::Utils::io;
 
-our (@ISA, @EXPORT, @EXPORT_OK);
+our (@ISA, @EXPORT, @EXPORT_OK, $VERSION);
 @ISA = qw(Exporter);
 
-@EXPORT = qw();
+@EXPORT = qw(getVersion);
 @EXPORT_OK = ();
+$VERSION = "1.0";
 
 our %visibleAttr = (sequence=>1, modif=>1, parentProtein=>1, start=>1, end=>1, readingFrame=>1, nTerm=>1, cTerm=>1, enzymatic=>1, enzyme=>1, aaBefore=>1, aaAfter=>1, nmc=>1, addProton=>1);
 our %aaList = split(//, 'A1C1D1E1F1G1H1I1K1L1M1N1P1Q1R1S1T1V1W1Y1');
@@ -551,7 +552,7 @@ sub modifAt
     $this->{modifType} = 'MS/MS';
     undef($this->{mass});
   }
-  return $this->{modif}[$pos+1];
+  return $this->{modif}[$pos+1] = $modif;
 
 } # modifAt
 
@@ -670,20 +671,6 @@ sub getMass
 } # getMass
 
 
-=head2 getMoZ(charge)
-
-
-=cut
-
-sub getMoZ
-{
-  my $this = shift;
-  my $charge=shift or croak "must provide a charge for Peptide->getMoZ";
-  my $m=$this->getMass();
-  $m-=InSilicoSpectro::InSilico::MassCalculator::getMass('el_H+') if ($this->addProton());
-  return $m/$charge+InSilicoSpectro::InSilico::MassCalculator::getMass('el_H+');
-}
-
 =head2 getLength
 
 Returns peptide sequence length.
@@ -727,7 +714,7 @@ sub print
 
   my $fdOut = defined($out) ? (new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) || croak("cannot open [$out]: $!"))) : \*STDOUT;
   print $fdOut $this->toString(), "\n";
-  print $fdOut "".(InSilicoSpectro::InSilico::MassCalculator::modifToString($this->modif()))."\n" if (defined($this->modif()));
+  print $fdOut InSilicoSpectro::InSilico::MassCalculator::modifToString($this->modif()), "\n" if (defined($this->modif()));
   print $fdOut $this->nmc(), " missed cleavage(s)\n" if (defined($this->nmc()));
   print $fdOut "Starts at ", $this->start(), "\n" if (defined($this->start()));
   print $fdOut "Ends at ", $this->end(), "\n" if (defined($this->end()));
@@ -743,9 +730,23 @@ sub print
 }
 
 
+=head1 FUNCTIONS
+
+=head2 getVersion
+
+Object definition version.
+
+=cut
+sub getVersion
+{
+  return $VERSION;
+
+} # getVersion
+
+
 =head1 EXAMPLES
 
-See t/InSilico/testPeptide.pl and t/InSilico/testCalcDigestOOP.pl.
+See Phenyx/InSilico/test/testPeptide.pl and Phenyx/InSilico/test/testCalcDigestOOP.pl.
 
 =head1 AUTHORS
 
