@@ -23,7 +23,7 @@
 #  Upper Austria University of Applied Science at Hagenberg
 #  Hauptstrasse 117
 #  A-4232 Hagenberg, Austria
-#  http://www.fhs-hagenberg.ac.at
+#  e-mail: jacques.colinge@fh-hagenberg.at or, alternatively, austrian_olav@yahoo.com
 
 
 =head1 testCalcDigest.pl
@@ -68,10 +68,10 @@ eval{
 
   if ($test == 2){
     # Test 2, trypsin regexp given by a string
-    my $protein = 'MCTMAPCTKGIPRKQWWEMMKPCKADFCV';
-    my $modif =   '::Cys_CAM::Oxidation:::::::::::::::Oxidation:::::::::::';
-    print "Protein:\n$protein\n$modif\n\nTrypsin/P regexp given by a string:\n";
-    my @result = digestByRegExp(protein=>$protein, modif=>$modif, methionine=>1, nmc=>1, enzyme=>'(?<=[KR])|(?=P)', minMass=>0);
+    my $protein = 'MCTMACTKGIPRKQWWEMMKPCKADFCV';
+    my $modif =   '::Cys_CAM::Oxidation::::::::::::::Oxidation:::::::::::';
+    print "Protein:\n$protein\n$modif\n\nTryptic regexp given by a string:\n";
+    my @result = digestByRegExp(protein=>$protein, modif=>$modif, methionine=>1, nmc=>1, enzyme=>'(?<=[KR])(?=[^P])');
     for (my $i = 0; $i < @{$result[0]}; $i++){
       print "$result[$digestIndexPept][$i]\t$result[$digestIndexStart][$i]\t",
 	    "$result[$digestIndexEnd][$i]\t$result[$digestIndexNmc][$i]\t",
@@ -120,7 +120,6 @@ eval{
 	    "$result[$digestIndexMass][$i]\t", modifToString($result[$digestIndexModif][$i]), "\n";
     }
   }
-
 };
 if ($@){
   carp($@);
